export { Anchor } from '@versini/ui-anchor';
export { Bubble } from '@versini/ui-bubble';
export { Button, ButtonIcon } from '@versini/ui-button';
export { Card } from '@versini/ui-card';
export { Footer } from '@versini/ui-footer';
export { Header } from '@versini/ui-header';
export { Main } from '@versini/ui-main';
export { Menu, MenuItem, MenuSeparator } from '@versini/ui-menu';
export { Panel } from '@versini/ui-panel';
export { Pill } from '@versini/ui-pill';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { SpacingProps } from '@versini/ui-private/dist/utilities';
import React$1 from 'react';

type SpinnerProps = {
	/**
	 * The mode of spinner to render. This will change the color of the spinner.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * A ref to the spinner element.
	 */
	spinnerRef?: React.RefObject<HTMLDivElement>;
	/**
	 * The type of spinner to render. This will change the layout of the spinner.
	 */
	type?: "circle" | "dots";
} & SpacingProps;

declare const Spinner: ({ spinnerRef, mode, type, spacing, }: SpinnerProps) => react_jsx_runtime.JSX.Element;

declare const TableCellSortDirections: {
    ASC: string;
    DESC: string;
};

type TableProps = {
	/**
	 * This attribute defines the caption (or title) of a table.
	 */
	caption?: React$1.ReactNode;
	/**
	 * If true, the table will be smaller.
	 */
	compact?: boolean;
	/**
	 * The max height of the table. It follows the CSS max-height property.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	maxHeight?: string;
	/**
	 * The mode of table. It defines the color of the table.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * If true, the table footer will be sticky.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	stickyFooter?: boolean;
	/**
	 * If true, the table header will be sticky.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	stickyHeader?: boolean;
	/**
	 * This attribute defines an alternative text that summarizes
	 * the content of the table. It is not visible but will be
	 * read out loud by screen readers to represent the table.
	 */
	summary?: string;
	/**
	 * CSS class to apply to the table wrapper.
	 */
	wrapperClassName?: string;
} & SpacingProps &
	React$1.HTMLAttributes<HTMLTableElement>;

type TableRowProps = React$1.HTMLAttributes<HTMLTableRowElement>;
type TableBodyProps = React$1.HTMLAttributes<HTMLTableSectionElement>;
type TableHeadProps = React$1.HTMLAttributes<HTMLTableSectionElement>;

type TableCellProps = {
	/**
	 * The type of cell.
	 * @default "td"
	 */
	component?: "td" | "th";
} & React$1.ThHTMLAttributes<HTMLTableCellElement> &
	React$1.TdHTMLAttributes<HTMLTableCellElement>;

type TableCellSortProps = {
	/**
	 * Unique identifier for the cell. This string will have to be onClick
	 * handler to sort on this particular cell.
	 */
	cellId: string;
	/**
	 * The label of the cell.
	 */
	children: string;
	/**
	 * The handler to be called when the cell is clicked.
	 */
	onClick: (event: React$1.MouseEvent<unknown>) => void;
	/**
	 * The direction of the sort.
	 */
	sortDirection:
		| typeof TableCellSortDirections.ASC
		| typeof TableCellSortDirections.DESC
		| false;
	/**
	 * The cellId that is currently sorted.
	 */
	sortedCell: string;
	/**
	 * Whether to align the cell content to the left, center, or right.
	 */
	align?: "left" | "center" | "right";
	/**
	 * The type of cell.
	 * @default "td"
	 */
	component?: "td" | "th";
	/**
	 * Pass through to the underlying ButtonIcon.
	 * The type of focus for the Button. This will change the color
	 * of the focus ring around the Button.
	 */
	focusMode?: "system" | "light" | "dark" | "alt-system";
	/**
	 * Pass through to the underlying ButtonIcon.
	 * The mode of Button. This will change the color of the Button.
	 */
	mode?: "system" | "light" | "dark" | "alt-system";
} & React$1.ThHTMLAttributes<HTMLTableCellElement> &
	React$1.TdHTMLAttributes<HTMLTableCellElement>;

declare const Table: ({ children, mode, caption, compact, summary, className, wrapperClassName, maxHeight, stickyHeader, stickyFooter, spacing, ...otherProps }: TableProps) => react_jsx_runtime.JSX.Element;
declare const TableHead: ({ children, className, ...otherProps }: TableHeadProps) => react_jsx_runtime.JSX.Element;
declare const TableFooter: ({ children, className, ...otherProps }: TableHeadProps) => react_jsx_runtime.JSX.Element;
declare const TableBody: ({ children, ...otherProps }: TableBodyProps) => react_jsx_runtime.JSX.Element;
declare const TableRow: ({ children, className, ...otherProps }: TableRowProps) => react_jsx_runtime.JSX.Element;
declare const TableCell: ({ children, component, className, ...otherProps }: TableCellProps) => react_jsx_runtime.JSX.Element;
declare const TableCellSort: ({ align, children, className, component, focusMode, mode, onClick, sortDirection, sortedCell, cellId, ...otherProps }: TableCellSortProps) => react_jsx_runtime.JSX.Element;

export { Spinner, Table, TableBody, TableCell, TableCellSort, TableCellSortDirections, TableFooter, TableHead, TableRow };
